@@ -608,10 +608,12 @@ pref("network.IDN.whitelist.cl", true);
 pref("network.IDN.whitelist.cn", true);
 pref("network.IDN.whitelist.de", true);
 pref("network.IDN.whitelist.dk", true);
+pref("network.IDN.whitelist.es", true);
 pref("network.IDN.whitelist.fi", true);
 pref("network.IDN.whitelist.gr", true);
 pref("network.IDN.whitelist.hu", true);
 pref("network.IDN.whitelist.io", true);
+pref("network.IDN.whitelist.ir", true);
 pref("network.IDN.whitelist.is", true);
 pref("network.IDN.whitelist.jp", true);
 pref("network.IDN.whitelist.kr", true);
@@ -690,7 +692,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 704 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
+//@line 706 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -838,7 +840,7 @@ pref("mousewheel.withmetakey.sysnumlines",true);
 
 // on platforms where scroll messages differ between horizontal scroll
 // and back/forward button events we can activate them by default
-//@line 886 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
+//@line 888 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 // disable horizontal scrolling to be able to use back/forward buttons
 pref("mousewheel.horizscroll.withnokey.action",2);
 pref("mousewheel.horizscroll.withnokey.numlines",-1);
@@ -855,7 +857,7 @@ pref("mousewheel.horizscroll.withaltkey.sysnumlines",false);
 pref("mousewheel.horizscroll.withmetakey.action",2);
 pref("mousewheel.horizscroll.withmetakey.numlines",-1);
 pref("mousewheel.horizscroll.withmetakey.sysnumlines",false);
-//@line 903 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
+//@line 905 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
 pref("profile.confirm_automigration",true);
 // profile.migration_behavior determines how the profiles root is set
@@ -998,15 +1000,15 @@ pref("dom.max_script_run_time", 10);
 
 pref("svg.enabled", true);
 
-//@line 1376 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
+//@line 1378 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1568 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
+//@line 1570 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1757 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
+//@line 1759 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1846 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
+//@line 1848 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1849 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
+//@line 1851 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1079,7 +1081,7 @@ pref("font.allow_double_byte_special_chars", true);
 
 // ar
 
-//@line 1922 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
+//@line 1924 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.name.serif.el", "serif");
 pref("font.name.sans-serif.el", "sans-serif");
@@ -1138,7 +1140,7 @@ pref("font.name.sans-serif.zh-HK", "sans-serif");
 pref("font.name.monospace.zh-HK", "monospace");
 
 // zh-TW
-//@line 2041 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
+//@line 2043 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.default.ar", "sans-serif");
 pref("font.size.variable.ar", 16);
@@ -1356,15 +1358,15 @@ pref("print.postscript.nativefont.zh-CN",          "");
 pref("print.postscript.nativefont.zh-TW",          "");
 pref("print.postscript.nativefont.zh-HK",          "");
 
-//@line 2261 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
+//@line 2263 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2329 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
+//@line 2331 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2355 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
+//@line 2357 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2375 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
-
-//@line 2383 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
+//@line 2377 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
 //@line 2385 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
+
+//@line 2387 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 pref("network.gnomevfs.supported-protocols", "smb:,sftp:");
